Tag newuser

## newuser create a new user

name
  newuser
xml namespace
  http://moyaproject.com/auth
defined
  /home/will/projects/moya/moya/applications/auth/logic/tags.xml (line 87)

Create a user

attributes
name | purpose | type | required?
--- | --- | --- | ---
dst | Destination | Reference | No
email |  | expression | Yes
first_name |  | expression | No
last_name |  | expression | No
lazy | Enable lazy evaluation | boolean | No
password |  | expression | No
username |  | expression | Yes

inherited attributes
name | purpose | type | required?
--- | --- | --- | ---
if | Conditional expression | expression | No